@@ -1,4 +1,5 @@
 import os
+import time
 import unittest
 import shutil
 
@@ -39,6 +40,8 @@ class TestPyhistory(unittest.TestCase):
         self.assertEqual(result.stdout, _join_lines(
             ['', '* some_message', '']))
 
+        time.sleep(1)
+
         run('pyhi add "next message"')
         result = run('pyhi list')
         self.assertEqual(result.stdout, _join_lines(
@@ -57,6 +60,7 @@ class TestPyhistory(unittest.TestCase):
     def _test_update(self, command):
         _load_fixture('history1.rst', 'HISTORY.rst')
         run('pyhi add some_message')
+        time.sleep(1)
         run('pyhi add "next message"')
         run('pyhi {} 1.0.6 --date today'.format(command))
         self.assertEqual(
@@ -65,8 +69,6 @@ class TestPyhistory(unittest.TestCase):
         )
 
     def test_pyhistory_when_not_in_history_file_directory(self):
-        command = 'update'
-
         _load_fixture('history1.rst', 'HISTORY.rst')
 
         original_working_dir = os.getcwd()
@@ -74,7 +76,9 @@ class TestPyhistory(unittest.TestCase):
         os.chdir('one/two')
 
         run('pyhi add some_message')
+        time.sleep(1)
         run('pyhi add "next message"')
+        time.sleep(1)
 
         self.assertEqual(0, len(os.listdir(os.getcwd())))
 
@@ -88,7 +92,7 @@ class TestPyhistory(unittest.TestCase):
             ['', '* some_message', '* next message', '']))
 
         os.chdir('one/two')
-        run('pyhi {} 1.0.6 --date today'.format(command))
+        run('pyhi update 1.0.6 --date today')
         os.chdir(original_working_dir)
 
         self.assertEqual(
@@ -116,7 +120,9 @@ class TestPyhistory(unittest.TestCase):
         _load_fixture('history1.rst', 'HISTORY.rst')
 
         run('pyhi add some_message')
+        time.sleep(1)
         run('pyhi add "next message"')
+        time.sleep(1)
 
         result = run('pyhi list')
         self.assertEqual(result.stdout, _join_lines(
@@ -134,6 +140,7 @@ class TestPyhistory(unittest.TestCase):
             ['', '* next message', '']))
 
         run('pyhi add test')
+        time.sleep(1)
         run('pyhi add test2')
 
         result = run('pyhi delete')
